==> qlcplus_4.13.1.orig.tar.xz: qlcplus-QLC-_4.13.1/plugins/artnet/src/ArtNet_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ArtNetPlugin</name>
    <message>
        <location filename="artnetplugin.cpp" line="97"/>
        <source>This plugin provides DMX output for devices supporting the ArtNet communication protocol.</source>
        <oldsource>This plugin provides output for devices supporting the ArtNet communication protocol.</oldsource>
        <translation>Dieses Plugin bietet Unterstützung für Geräte mit dem ArtNet-Kommunikationsprotokoll.</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="144"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="148"/>
        <location filename="artnetplugin.cpp" line="298"/>
        <source>Status: Not open</source>
        <translation>Status: Nicht geöffnet</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="151"/>
        <source>Status: Open</source>
        <translation>Geöffnet</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="156"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="158"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="159"/>
        <source>Can receive nodes information</source>
        <oldsource>Can receive node information</oldsource>
        <translation>Kann Knoteninformationen empfangen</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="162"/>
        <source>Nodes discovered: </source>
        <translation>Knoten (Nodes) erkannt: </translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="165"/>
        <source>Packets sent: </source>
        <translation>Gesendete Pakete: </translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="294"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="303"/>
        <source>Bind failed</source>
        <translation>Bind fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="305"/>
        <source>Open</source>
        <translation>Offen</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="306"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="309"/>
        <source>Packets received: </source>
        <translation>Empfangene Pakete: </translation>
    </message>
</context>
<context>
    <name>ConfigureArtNet</name>
    <message>
        <location filename="configureartnet.ui" line="33"/>
        <source>Configure ArtNet Plugin</source>
        <translation>ArtNet-Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Universum konfigurieren</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="49"/>
        <source>Configuration of the patched universes</source>
        <translation>Konfiguration der gepatchen Universen</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="57"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="62"/>
        <source>Universe</source>
        <translation>Universum</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="67"/>
        <source>IP Address</source>
        <translation>IP Adresse</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="72"/>
        <source>ArtNet Universe</source>
        <translation>ArtNet Universum</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="77"/>
        <source>Transmission Mode</source>
        <translation>Übertragungmodus</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="87"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation>Sekunden um auf die Bereitschaft des Interfaces zu warten</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="120"/>
        <source>Nodes Tree</source>
        <translation>Knoten (Nodes) Baum</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="130"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="135"/>
        <source>Short Name</source>
        <translation>Abgekürzter Name</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="140"/>
        <source>Long Name</source>
        <translation>Kompletter Name</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="86"/>
        <source>%1 nodes</source>
        <translation>%1 Knoten</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="124"/>
        <source>Inputs</source>
        <translation>Eingänge</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="130"/>
        <source>Outputs</source>
        <translation>Ausgänge</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="181"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="182"/>
        <source>Full</source>
        <translation>Vollständig</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="183"/>
        <source>Partial</source>
        <translation>Teilweise</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="198"/>
        <source>Invalid IP</source>
        <translation>Ungültige IP</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="198"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 ist keine gültige IP.
Bitte vor Bestätigung korrigieren.</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.3.orig.tar.xz: qlcplus-QLC-_4.14.3/plugins/artnet/src/ArtNet_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ArtNetPlugin</name>
    <message>
        <location filename="artnetplugin.cpp" line="97"/>
        <source>This plugin provides DMX output for devices supporting the ArtNet communication protocol.</source>
        <oldsource>This plugin provides output for devices supporting the ArtNet communication protocol.</oldsource>
        <translation>Dieses Plugin bietet Unterstützung für Geräte mit dem ArtNet-Kommunikationsprotokoll.</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="144"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="148"/>
        <location filename="artnetplugin.cpp" line="298"/>
        <source>Status: Not open</source>
        <translation>Status: Nicht geöffnet</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="151"/>
        <source>Status: Open</source>
        <translation>Geöffnet</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="156"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="158"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="159"/>
        <source>Can receive nodes information</source>
        <oldsource>Can receive node information</oldsource>
        <translation>Kann Knoteninformationen empfangen</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="162"/>
        <source>Nodes discovered: </source>
        <translation>Knoten (Nodes) erkannt: </translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="165"/>
        <source>Packets sent: </source>
        <translation>Gesendete Pakete: </translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="294"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="303"/>
        <source>Bind failed</source>
        <translation>Bind fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="305"/>
        <source>Open</source>
        <translation>Offen</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="306"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="artnetplugin.cpp" line="309"/>
        <source>Packets received: </source>
        <translation>Empfangene Pakete: </translation>
    </message>
</context>
<context>
    <name>ConfigureArtNet</name>
    <message>
        <location filename="configureartnet.ui" line="33"/>
        <source>Configure ArtNet Plugin</source>
        <translation>ArtNet-Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Universum konfigurieren</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="49"/>
        <source>Configuration of the patched universes</source>
        <translation>Konfiguration der gepatchten Universen</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="57"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="62"/>
        <source>Universe</source>
        <translation>Universum</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="67"/>
        <source>IP Address</source>
        <translation>IP Adresse</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="72"/>
        <source>ArtNet Universe</source>
        <translation>ArtNet Universum</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="77"/>
        <source>Transmission Mode</source>
        <translation>Übertragungsmodus</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="87"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation>Sekunden, um auf die Bereitschaft des Interfaces zu warten</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="120"/>
        <source>Nodes Tree</source>
        <translation>Knoten (Nodes) Baum</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="130"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="135"/>
        <source>Short Name</source>
        <translation>Abgekürzter Name</translation>
    </message>
    <message>
        <location filename="configureartnet.ui" line="140"/>
        <source>Long Name</source>
        <translation>Kompletter Name</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="90"/>
        <source>%1 nodes</source>
        <translation>%1 Knoten</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="128"/>
        <source>Inputs</source>
        <translation>Eingänge</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="134"/>
        <source>Outputs</source>
        <translation>Ausgänge</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="185"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="186"/>
        <source>Full</source>
        <translation>Vollständig</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="187"/>
        <source>Partial</source>
        <translation>Teilweise</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="202"/>
        <source>Invalid IP</source>
        <translation>Ungültige IP</translation>
    </message>
    <message>
        <location filename="configureartnet.cpp" line="202"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 ist keine gültige IP.
Bitte vor Bestätigung korrigieren.</translation>
    </message>
</context>
</TS>
